// Code generated by software.amazon.smithy.rust.codegen.smithy-rs. DO NOT EDIT.
#[derive(Debug)]
pub(crate) struct Handle<
    C = aws_smithy_client::erase::DynConnector,
    M = aws_hyper::AwsMiddleware,
    R = aws_smithy_client::retry::Standard,
> {
    client: aws_smithy_client::Client<C, M, R>,
    conf: crate::Config,
}

/// Client for Amazon CloudSearch Domain
///
/// Client for invoking operations on Amazon CloudSearch Domain. Each operation on Amazon CloudSearch Domain is a method on this
/// this struct. `.send()` MUST be invoked on the generated operations to dispatch the request to the service.
///
/// # Examples
/// **Constructing a client and invoking an operation**
/// ```rust,no_run
/// # async fn docs() {
///     // create a shared configuration. This can be used & shared between multiple service clients.
///     let shared_config = aws_config::load_from_env().await;
///     let client = aws_sdk_cloudsearchdomain::Client::new(&shared_config);
///     // invoke an operation
///     /* let rsp = client
///         .<operationname>().
///         .<param>("some value")
///         .send().await; */
/// # }
/// ```
/// **Constructing a client with custom configuration**
/// ```rust,no_run
/// use aws_config::RetryConfig;
/// # async fn docs() {
///     let shared_config = aws_config::load_from_env().await;
///     let config = aws_sdk_cloudsearchdomain::config::Builder::from(&shared_config)
///         .retry_config(RetryConfig::disabled())
///         .build();
///     let client = aws_sdk_cloudsearchdomain::Client::from_conf(config);
/// # }
#[derive(std::fmt::Debug)]
pub struct Client<
    C = aws_smithy_client::erase::DynConnector,
    M = aws_hyper::AwsMiddleware,
    R = aws_smithy_client::retry::Standard,
> {
    handle: std::sync::Arc<Handle<C, M, R>>,
}

impl<C, M, R> std::clone::Clone for Client<C, M, R> {
    fn clone(&self) -> Self {
        Self {
            handle: self.handle.clone(),
        }
    }
}

#[doc(inline)]
pub use aws_smithy_client::Builder;

impl<C, M, R> From<aws_smithy_client::Client<C, M, R>> for Client<C, M, R> {
    fn from(client: aws_smithy_client::Client<C, M, R>) -> Self {
        Self::with_config(client, crate::Config::builder().build())
    }
}

impl<C, M, R> Client<C, M, R> {
    /// Creates a client with the given service configuration.
    pub fn with_config(client: aws_smithy_client::Client<C, M, R>, conf: crate::Config) -> Self {
        Self {
            handle: std::sync::Arc::new(Handle { client, conf }),
        }
    }

    /// Returns the client's configuration.
    pub fn conf(&self) -> &crate::Config {
        &self.handle.conf
    }
}
impl<C, M, R> Client<C, M, R>
where
    C: aws_smithy_client::bounds::SmithyConnector,
    M: aws_smithy_client::bounds::SmithyMiddleware<C>,
    R: aws_smithy_client::retry::NewRequestPolicy,
{
    /// Constructs a fluent builder for the `Search` operation.
    ///
    /// See [`Search`](crate::client::fluent_builders::Search) for more information about the
    /// operation and its arguments.
    pub fn search(&self) -> fluent_builders::Search<C, M, R> {
        fluent_builders::Search::new(self.handle.clone())
    }
    /// Constructs a fluent builder for the `Suggest` operation.
    ///
    /// See [`Suggest`](crate::client::fluent_builders::Suggest) for more information about the
    /// operation and its arguments.
    pub fn suggest(&self) -> fluent_builders::Suggest<C, M, R> {
        fluent_builders::Suggest::new(self.handle.clone())
    }
    /// Constructs a fluent builder for the `UploadDocuments` operation.
    ///
    /// See [`UploadDocuments`](crate::client::fluent_builders::UploadDocuments) for more information about the
    /// operation and its arguments.
    pub fn upload_documents(&self) -> fluent_builders::UploadDocuments<C, M, R> {
        fluent_builders::UploadDocuments::new(self.handle.clone())
    }
}
pub mod fluent_builders {
    //!
    //! Utilities to ergonomically construct a request to the service.
    //!
    //! Fluent builders are created through the [`Client`](crate::client::Client) by calling
    //! one if its operation methods. After parameters are set using the builder methods,
    //! the `send` method can be called to initiate the request.
    //!
    /// Fluent builder constructing a request to `Search`.
    ///
    /// <p>Retrieves a list of documents that match the specified search criteria. How you specify the search criteria depends on which query parser you use. Amazon CloudSearch supports four query parsers:</p>
    /// <ul>
    /// <li><code>simple</code>: search all <code>text</code> and <code>text-array</code> fields for the specified string. Search for phrases, individual terms, and prefixes. </li>
    /// <li><code>structured</code>: search specific fields, construct compound queries using Boolean operators, and use advanced features such as term boosting and proximity searching.</li>
    /// <li><code>lucene</code>: specify search criteria using the Apache Lucene query parser syntax.</li>
    /// <li><code>dismax</code>: specify search criteria using the simplified subset of the Apache Lucene query parser syntax defined by the DisMax query parser.</li>
    /// </ul>
    /// <p>For more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching.html">Searching Your Data</a> in the <i>Amazon CloudSearch Developer Guide</i>.</p>
    /// <p>The endpoint for submitting <code>Search</code> requests is domain-specific. You submit search requests to a domain's search endpoint. To get the search endpoint for your domain, use the Amazon CloudSearch configuration service <code>DescribeDomains</code> action. A domain's endpoints are also displayed on the domain dashboard in the Amazon CloudSearch console. </p>
    #[derive(std::fmt::Debug)]
    pub struct Search<
        C = aws_smithy_client::erase::DynConnector,
        M = aws_hyper::AwsMiddleware,
        R = aws_smithy_client::retry::Standard,
    > {
        handle: std::sync::Arc<super::Handle<C, M, R>>,
        inner: crate::input::search_input::Builder,
    }
    impl<C, M, R> Search<C, M, R>
    where
        C: aws_smithy_client::bounds::SmithyConnector,
        M: aws_smithy_client::bounds::SmithyMiddleware<C>,
        R: aws_smithy_client::retry::NewRequestPolicy,
    {
        /// Creates a new `Search`.
        pub(crate) fn new(handle: std::sync::Arc<super::Handle<C, M, R>>) -> Self {
            Self {
                handle,
                inner: Default::default(),
            }
        }

        /// Sends the request and returns the response.
        ///
        /// If an error occurs, an `SdkError` will be returned with additional details that
        /// can be matched against.
        ///
        /// By default, any retryable failures will be retried twice. Retry behavior
        /// is configurable with the [RetryConfig](aws_smithy_types::retry::RetryConfig), which can be
        /// set when configuring the client.
        pub async fn send(
            self,
        ) -> std::result::Result<
            crate::output::SearchOutput,
            aws_smithy_http::result::SdkError<crate::error::SearchError>,
        >
        where
            R::Policy: aws_smithy_client::bounds::SmithyRetryPolicy<
                crate::input::SearchInputOperationOutputAlias,
                crate::output::SearchOutput,
                crate::error::SearchError,
                crate::input::SearchInputOperationRetryAlias,
            >,
        {
            let input = self.inner.build().map_err(|err| {
                aws_smithy_http::result::SdkError::ConstructionFailure(err.into())
            })?;
            let op = input
                .make_operation(&self.handle.conf)
                .await
                .map_err(|err| {
                    aws_smithy_http::result::SdkError::ConstructionFailure(err.into())
                })?;
            self.handle.client.call(op).await
        }
        /// <p>Retrieves a cursor value you can use to page through large result sets.
        /// Use the <code>size</code> parameter to control the number of hits to include in each response. You can specify either the <code>cursor</code> or
        /// <code>start</code> parameter in a request; they are mutually exclusive. To get the first cursor, set the cursor value to <code>initial</code>. In subsequent requests, specify the cursor value returned in the hits section of the response. </p>
        /// <p>For more
        /// information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/paginating-results.html">Paginating Results</a> in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn cursor(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.cursor(inp);
            self
        }
        /// <p>Retrieves a cursor value you can use to page through large result sets.
        /// Use the <code>size</code> parameter to control the number of hits to include in each response. You can specify either the <code>cursor</code> or
        /// <code>start</code> parameter in a request; they are mutually exclusive. To get the first cursor, set the cursor value to <code>initial</code>. In subsequent requests, specify the cursor value returned in the hits section of the response. </p>
        /// <p>For more
        /// information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/paginating-results.html">Paginating Results</a> in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn set_cursor(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_cursor(input);
            self
        }
        /// <p>Defines one or more numeric expressions that can be used to sort results or specify search or filter
        /// criteria. You can also specify expressions as return fields. </p>
        /// <p>You specify the expressions in JSON using the form <code>{"EXPRESSIONNAME":"EXPRESSION"}</code>. You can define and use multiple expressions in a search request. For example:</p>
        /// <p><code>
        /// {"expression1":"_score*rating", "expression2":"(1/rank)*year"}
        /// </code> </p>
        /// <p>For information about the variables, operators, and functions you can use in expressions, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-expressions.html#writing-expressions">Writing Expressions</a>
        /// in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn expr(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.expr(inp);
            self
        }
        /// <p>Defines one or more numeric expressions that can be used to sort results or specify search or filter
        /// criteria. You can also specify expressions as return fields. </p>
        /// <p>You specify the expressions in JSON using the form <code>{"EXPRESSIONNAME":"EXPRESSION"}</code>. You can define and use multiple expressions in a search request. For example:</p>
        /// <p><code>
        /// {"expression1":"_score*rating", "expression2":"(1/rank)*year"}
        /// </code> </p>
        /// <p>For information about the variables, operators, and functions you can use in expressions, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-expressions.html#writing-expressions">Writing Expressions</a>
        /// in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn set_expr(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_expr(input);
            self
        }
        /// <p>Specifies one or more fields for which to get facet information, and options that control how the facet information is returned. Each specified field must be facet-enabled in the domain configuration. The fields and options are specified in JSON using the form <code>{"FIELD":{"OPTION":VALUE,"OPTION:"STRING"},"FIELD":{"OPTION":VALUE,"OPTION":"STRING"}}</code>.</p>
        /// <p>You can specify the following faceting options:</p>
        /// <ul>
        /// <li>
        /// <p><code>buckets</code> specifies an array of the facet values or
        /// ranges to count. Ranges are specified using the same syntax that you use to search for a range of values.
        /// For more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching-ranges.html">
        /// Searching for a Range of Values</a> in the <i>Amazon CloudSearch Developer Guide</i>. Buckets are returned in the order they
        /// are specified in the request. The <code>sort</code> and <code>size</code> options are
        /// not valid if you specify <code>buckets</code>.</p>
        /// </li>
        /// <li>
        /// <p><code>size</code> specifies the maximum number of facets to include in the results. By
        /// default, Amazon CloudSearch returns counts for the top 10. The
        /// <code>size</code> parameter is only valid when you specify
        /// the <code>sort</code> option; it cannot be used in conjunction
        /// with <code>buckets</code>.</p>
        /// </li>
        /// <li>
        /// <p><code>sort</code> specifies how you want to sort the facets in
        /// the results: <code>bucket</code> or <code>count</code>. Specify
        /// <code>bucket</code> to sort alphabetically or numerically by
        /// facet value (in ascending order). Specify <code>count</code> to
        /// sort by the facet counts computed for each facet value (in
        /// descending order). To retrieve facet counts for particular
        /// values or ranges of values, use the <code>buckets</code> option
        /// instead of <code>sort</code>. </p>
        /// </li>
        /// </ul>
        /// <p>If no facet options are specified, facet counts are computed for all field values, the facets are sorted by facet count, and the top 10 facets are returned in the results.</p>
        ///
        /// <p>To count particular buckets of values, use the <code>buckets</code> option. For example, the following request uses the <code>buckets</code> option to calculate and return facet counts by decade.</p>
        /// <p><code>
        /// {"year":{"buckets":["[1970,1979]","[1980,1989]","[1990,1999]","[2000,2009]","[2010,}"]}}
        /// </code></p>
        ///
        /// <p>To sort facets by facet count, use the <code>count</code> option. For example, the following request sets the <code>sort</code> option to <code>count</code> to sort the facet values by facet count, with the facet
        /// values that have the most matching documents listed first. Setting the <code>size</code> option to 3 returns only the top three facet values.</p>
        /// <p><code>
        /// {"year":{"sort":"count","size":3}}
        /// </code></p>
        ///
        /// <p>To sort the facets by value, use the <code>bucket</code> option. For example, the following  request sets the <code>sort</code> option to <code>bucket</code> to sort the facet values numerically by year, with earliest year listed first. </p>
        /// <p><code>
        /// {"year":{"sort":"bucket"}}
        /// </code></p>
        /// <p>For more
        /// information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/faceting.html">Getting and Using Facet Information</a>
        /// in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn facet(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.facet(inp);
            self
        }
        /// <p>Specifies one or more fields for which to get facet information, and options that control how the facet information is returned. Each specified field must be facet-enabled in the domain configuration. The fields and options are specified in JSON using the form <code>{"FIELD":{"OPTION":VALUE,"OPTION:"STRING"},"FIELD":{"OPTION":VALUE,"OPTION":"STRING"}}</code>.</p>
        /// <p>You can specify the following faceting options:</p>
        /// <ul>
        /// <li>
        /// <p><code>buckets</code> specifies an array of the facet values or
        /// ranges to count. Ranges are specified using the same syntax that you use to search for a range of values.
        /// For more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching-ranges.html">
        /// Searching for a Range of Values</a> in the <i>Amazon CloudSearch Developer Guide</i>. Buckets are returned in the order they
        /// are specified in the request. The <code>sort</code> and <code>size</code> options are
        /// not valid if you specify <code>buckets</code>.</p>
        /// </li>
        /// <li>
        /// <p><code>size</code> specifies the maximum number of facets to include in the results. By
        /// default, Amazon CloudSearch returns counts for the top 10. The
        /// <code>size</code> parameter is only valid when you specify
        /// the <code>sort</code> option; it cannot be used in conjunction
        /// with <code>buckets</code>.</p>
        /// </li>
        /// <li>
        /// <p><code>sort</code> specifies how you want to sort the facets in
        /// the results: <code>bucket</code> or <code>count</code>. Specify
        /// <code>bucket</code> to sort alphabetically or numerically by
        /// facet value (in ascending order). Specify <code>count</code> to
        /// sort by the facet counts computed for each facet value (in
        /// descending order). To retrieve facet counts for particular
        /// values or ranges of values, use the <code>buckets</code> option
        /// instead of <code>sort</code>. </p>
        /// </li>
        /// </ul>
        /// <p>If no facet options are specified, facet counts are computed for all field values, the facets are sorted by facet count, and the top 10 facets are returned in the results.</p>
        ///
        /// <p>To count particular buckets of values, use the <code>buckets</code> option. For example, the following request uses the <code>buckets</code> option to calculate and return facet counts by decade.</p>
        /// <p><code>
        /// {"year":{"buckets":["[1970,1979]","[1980,1989]","[1990,1999]","[2000,2009]","[2010,}"]}}
        /// </code></p>
        ///
        /// <p>To sort facets by facet count, use the <code>count</code> option. For example, the following request sets the <code>sort</code> option to <code>count</code> to sort the facet values by facet count, with the facet
        /// values that have the most matching documents listed first. Setting the <code>size</code> option to 3 returns only the top three facet values.</p>
        /// <p><code>
        /// {"year":{"sort":"count","size":3}}
        /// </code></p>
        ///
        /// <p>To sort the facets by value, use the <code>bucket</code> option. For example, the following  request sets the <code>sort</code> option to <code>bucket</code> to sort the facet values numerically by year, with earliest year listed first. </p>
        /// <p><code>
        /// {"year":{"sort":"bucket"}}
        /// </code></p>
        /// <p>For more
        /// information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/faceting.html">Getting and Using Facet Information</a>
        /// in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn set_facet(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_facet(input);
            self
        }
        /// <p>Specifies a structured query that filters the results of a search without affecting how the results are scored and sorted. You use <code>filterQuery</code> in conjunction with the <code>query</code> parameter to filter the documents that match the constraints specified in the <code>query</code> parameter. Specifying a filter controls only which matching documents are included in the results, it has no effect on how they are scored and sorted. The <code>filterQuery</code> parameter supports the full structured query syntax. </p>
        /// <p>For more information about using filters, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/filtering-results.html">Filtering Matching Documents</a>
        /// in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn filter_query(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.filter_query(inp);
            self
        }
        /// <p>Specifies a structured query that filters the results of a search without affecting how the results are scored and sorted. You use <code>filterQuery</code> in conjunction with the <code>query</code> parameter to filter the documents that match the constraints specified in the <code>query</code> parameter. Specifying a filter controls only which matching documents are included in the results, it has no effect on how they are scored and sorted. The <code>filterQuery</code> parameter supports the full structured query syntax. </p>
        /// <p>For more information about using filters, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/filtering-results.html">Filtering Matching Documents</a>
        /// in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn set_filter_query(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_filter_query(input);
            self
        }
        /// <p>Retrieves highlights for matches in the specified <code>text</code> or
        /// <code>text-array</code> fields. Each specified field must be highlight enabled in the domain configuration. The fields and options are specified in JSON using the form <code>{"FIELD":{"OPTION":VALUE,"OPTION:"STRING"},"FIELD":{"OPTION":VALUE,"OPTION":"STRING"}}</code>.</p>
        /// <p>You can specify the following highlight options:</p>
        /// <ul>
        /// <li>
        /// <code>format</code>: specifies the format of the data in the
        /// text field: <code>text</code> or <code>html</code>. When data is
        /// returned as HTML, all non-alphanumeric characters are encoded.
        /// The default is <code>html</code>.
        /// </li>
        /// <li>
        /// <code>max_phrases</code>: specifies the maximum number of
        /// occurrences of the search term(s) you want to highlight. By
        /// default, the first occurrence is highlighted.
        /// </li>
        /// <li>
        /// <code>pre_tag</code>: specifies the string to prepend to an
        /// occurrence of a search term. The default for HTML highlights is
        /// <code>&lt;em&gt;</code>. The default for text highlights is
        /// <code>*</code>.
        /// </li>
        /// <li>
        /// <code>post_tag</code>: specifies the string to append to an
        /// occurrence of a search term. The default for HTML highlights is
        /// <code>&lt;/em&gt;</code>. The default for text highlights is
        /// <code>*</code>.
        /// </li>
        /// </ul>
        /// <p>If no highlight options are specified for a field, the returned field text is treated as HTML and the first match is
        /// highlighted with emphasis tags:  <code>&lt;em>search-term&lt;/em&gt;</code>.</p>
        /// <p>For example, the following request retrieves highlights for the <code>actors</code> and <code>title</code> fields.</p>
        /// <p> <code>{
        /// "actors": {},
        /// "title": {"format": "text","max_phrases": 2,"pre_tag": "<b>","post_tag": "</b>"}
        /// }</code></p>
        pub fn highlight(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.highlight(inp);
            self
        }
        /// <p>Retrieves highlights for matches in the specified <code>text</code> or
        /// <code>text-array</code> fields. Each specified field must be highlight enabled in the domain configuration. The fields and options are specified in JSON using the form <code>{"FIELD":{"OPTION":VALUE,"OPTION:"STRING"},"FIELD":{"OPTION":VALUE,"OPTION":"STRING"}}</code>.</p>
        /// <p>You can specify the following highlight options:</p>
        /// <ul>
        /// <li>
        /// <code>format</code>: specifies the format of the data in the
        /// text field: <code>text</code> or <code>html</code>. When data is
        /// returned as HTML, all non-alphanumeric characters are encoded.
        /// The default is <code>html</code>.
        /// </li>
        /// <li>
        /// <code>max_phrases</code>: specifies the maximum number of
        /// occurrences of the search term(s) you want to highlight. By
        /// default, the first occurrence is highlighted.
        /// </li>
        /// <li>
        /// <code>pre_tag</code>: specifies the string to prepend to an
        /// occurrence of a search term. The default for HTML highlights is
        /// <code>&lt;em&gt;</code>. The default for text highlights is
        /// <code>*</code>.
        /// </li>
        /// <li>
        /// <code>post_tag</code>: specifies the string to append to an
        /// occurrence of a search term. The default for HTML highlights is
        /// <code>&lt;/em&gt;</code>. The default for text highlights is
        /// <code>*</code>.
        /// </li>
        /// </ul>
        /// <p>If no highlight options are specified for a field, the returned field text is treated as HTML and the first match is
        /// highlighted with emphasis tags:  <code>&lt;em>search-term&lt;/em&gt;</code>.</p>
        /// <p>For example, the following request retrieves highlights for the <code>actors</code> and <code>title</code> fields.</p>
        /// <p> <code>{
        /// "actors": {},
        /// "title": {"format": "text","max_phrases": 2,"pre_tag": "<b>","post_tag": "</b>"}
        /// }</code></p>
        pub fn set_highlight(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_highlight(input);
            self
        }
        /// <p>Enables partial results to be returned if one or more index partitions are unavailable. When your search index is partitioned across multiple search instances, by default Amazon CloudSearch only returns results if every partition can be queried. This means that the failure of a single search instance can result in 5xx (internal server) errors. When you enable partial results, Amazon CloudSearch returns whatever results are available and includes the percentage of documents searched in the search results (percent-searched). This enables you to more gracefully degrade your users' search experience. For example, rather than displaying no results, you could display the partial results and a message indicating that the results might be incomplete due to a temporary system outage.</p>
        pub fn partial(mut self, inp: bool) -> Self {
            self.inner = self.inner.partial(inp);
            self
        }
        /// <p>Enables partial results to be returned if one or more index partitions are unavailable. When your search index is partitioned across multiple search instances, by default Amazon CloudSearch only returns results if every partition can be queried. This means that the failure of a single search instance can result in 5xx (internal server) errors. When you enable partial results, Amazon CloudSearch returns whatever results are available and includes the percentage of documents searched in the search results (percent-searched). This enables you to more gracefully degrade your users' search experience. For example, rather than displaying no results, you could display the partial results and a message indicating that the results might be incomplete due to a temporary system outage.</p>
        pub fn set_partial(mut self, input: std::option::Option<bool>) -> Self {
            self.inner = self.inner.set_partial(input);
            self
        }
        /// <p>Specifies the search criteria for the request. How you specify the search
        /// criteria depends on the query parser used for the request and the parser options
        /// specified in the <code>queryOptions</code> parameter. By default,
        /// the <code>simple</code> query parser is used to process requests. To use
        /// the <code>structured</code>, <code>lucene</code>, or <code>dismax</code> query parser,
        /// you must also specify the <code>queryParser</code> parameter. </p>
        /// <p>For more information about specifying search criteria, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching.html">Searching Your Data</a> in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn query(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.query(inp);
            self
        }
        /// <p>Specifies the search criteria for the request. How you specify the search
        /// criteria depends on the query parser used for the request and the parser options
        /// specified in the <code>queryOptions</code> parameter. By default,
        /// the <code>simple</code> query parser is used to process requests. To use
        /// the <code>structured</code>, <code>lucene</code>, or <code>dismax</code> query parser,
        /// you must also specify the <code>queryParser</code> parameter. </p>
        /// <p>For more information about specifying search criteria, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching.html">Searching Your Data</a> in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn set_query(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_query(input);
            self
        }
        /// <p>Configures options for the query parser specified in the <code>queryParser</code> parameter. You specify the options in JSON using the following form <code>{"OPTION1":"VALUE1","OPTION2":VALUE2"..."OPTIONN":"VALUEN"}.</code></p>
        ///
        /// <p>The options you can configure vary according to which parser you use:</p>
        /// <ul>
        /// <li><code>defaultOperator</code>: The default operator used to combine individual terms in the search string. For example: <code>defaultOperator: 'or'</code>. For the <code>dismax</code> parser, you specify a percentage that represents the percentage of terms in the search string (rounded down) that must match, rather than a default operator. A value of <code>0%</code> is the equivalent to OR, and a value of <code>100%</code> is equivalent to AND. The percentage must be specified as a value in the range 0-100 followed by the percent (%) symbol. For example, <code>defaultOperator: 50%</code>. Valid values: <code>and</code>, <code>or</code>, a percentage in the range 0%-100% (<code>dismax</code>). Default: <code>and</code> (<code>simple</code>, <code>structured</code>, <code>lucene</code>) or <code>100</code> (<code>dismax</code>). Valid for: <code>simple</code>, <code>structured</code>, <code>lucene</code>, and <code>dismax</code>.</li>
        /// <li><code>fields</code>: An array of the fields to search when no fields are specified in a search. If no fields are specified in a search and this option is not specified, all text and text-array fields are searched. You can specify a weight for each field to control the relative importance of each field when Amazon CloudSearch calculates relevance scores. To specify a field weight, append a caret (<code>^</code>) symbol and the weight to the field name. For example, to boost the importance of the <code>title</code> field over the <code>description</code> field you could specify: <code>"fields":["title^5","description"]</code>.  Valid values: The name of any configured field and an optional numeric value greater than zero. Default: All <code>text</code> and <code>text-array</code> fields. Valid for: <code>simple</code>, <code>structured</code>, <code>lucene</code>, and <code>dismax</code>.</li>
        /// <li><code>operators</code>: An array of the operators or special characters you want to
        /// disable for the simple query parser. If you disable the
        /// <code>and</code>, <code>or</code>, or <code>not</code>
        /// operators, the corresponding operators (<code>+</code>,
        /// <code>|</code>, <code>-</code>) have no special meaning and
        /// are dropped from the search string. Similarly, disabling
        /// <code>prefix</code> disables the wildcard operator
        /// (<code>*</code>) and disabling <code>phrase</code> disables
        /// the ability to search for phrases by enclosing phrases in double
        /// quotes. Disabling precedence disables the ability to control
        /// order of precedence using parentheses. Disabling <code>near</code> disables
        /// the ability to use the ~ operator to perform a sloppy phrase search.
        /// Disabling the <code>fuzzy</code> operator disables the ability to use the ~ operator to perform a fuzzy search.
        /// <code>escape</code> disables the ability to use a backslash
        /// (<code>\</code>) to escape special characters within the
        /// search string. Disabling whitespace is an advanced option that
        /// prevents the parser from tokenizing on whitespace, which can be
        /// useful for Vietnamese. (It prevents Vietnamese words from being
        /// split incorrectly.) For example, you could disable all operators
        /// other than the phrase operator to support just simple term and
        /// phrase queries: <code>"operators":["and","not","or",
        /// "prefix"]</code>. Valid values: <code>and</code>, <code>escape</code>,
        /// <code>fuzzy</code>, <code>near</code>, <code>not</code>, <code>or</code>,
        /// <code>phrase</code>, <code>precedence</code>, <code>prefix</code>,
        /// <code>whitespace</code>. Default: All
        /// operators and special characters are enabled. Valid for:
        /// <code>simple</code>.</li>
        /// <li><code>phraseFields</code>: An array of the <code>text</code> or <code>text-array</code> fields you want to use for
        /// phrase searches. When the terms in the search string appear in
        /// close proximity within a field, the field scores higher. You can
        /// specify a weight for each field to boost that score. The
        /// <code>phraseSlop</code> option controls how much the matches
        /// can deviate from the search string and still be boosted. To
        /// specify a field weight, append a caret (<code>^</code>) symbol
        /// and the weight to the field name. For example, to boost phrase
        /// matches in the <code>title</code> field over the
        /// <code>abstract</code> field, you could specify:
        /// <code>"phraseFields":["title^3",
        /// "plot"]</code>
        /// Valid values: The name of any <code>text</code> or
        /// <code>text-array</code> field and an optional numeric value greater than zero. Default: No fields. If you don't specify any fields with <code>phraseFields</code>, proximity scoring is disabled even if <code>phraseSlop</code> is specified. Valid
        /// for: <code>dismax</code>.</li>
        /// <li><code>phraseSlop</code>: An integer value that specifies how much matches can deviate from the search phrase and still be boosted according to the weights specified in the <code>phraseFields</code> option; for example, <code>phraseSlop: 2</code>. You must also specify <code>phraseFields</code> to enable proximity scoring. Valid values: positive integers. Default: 0. Valid for: <code>dismax</code>.</li>
        /// <li><code>explicitPhraseSlop</code>: An integer value that specifies how much a match can deviate from the search phrase when the phrase is enclosed in double quotes in the search string. (Phrases that exceed this proximity distance are not considered a match.) For example, to specify a slop of three for dismax phrase queries, you would specify <code>"explicitPhraseSlop":3</code>. Valid values: positive integers. Default: 0. Valid for: <code>dismax</code>.</li>
        /// <li><code>tieBreaker</code>: When a term in the search string is found in a document's field, a score is calculated for that field based on how common the word is in that field compared to other documents. If the term occurs in multiple fields within a document, by default only the highest scoring field contributes to the document's overall score. You can specify a <code>tieBreaker</code> value to enable the matches in lower-scoring fields to contribute to the document's score. That way, if two documents have the same max field score for a particular term, the score for the document that has matches in more fields will be higher. The formula for calculating the score with a tieBreaker is <code>(max field score) + (tieBreaker) * (sum of the scores for the rest of the matching fields)</code>.
        ///
        /// Set <code>tieBreaker</code> to 0 to disregard all but the highest scoring field (pure max): <code>"tieBreaker":0</code>. Set to 1 to sum the scores from all fields (pure sum): <code>"tieBreaker":1</code>. Valid values: 0.0 to 1.0. Default: 0.0. Valid for: <code>dismax</code>.
        /// </li>
        /// </ul>
        pub fn query_options(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.query_options(inp);
            self
        }
        /// <p>Configures options for the query parser specified in the <code>queryParser</code> parameter. You specify the options in JSON using the following form <code>{"OPTION1":"VALUE1","OPTION2":VALUE2"..."OPTIONN":"VALUEN"}.</code></p>
        ///
        /// <p>The options you can configure vary according to which parser you use:</p>
        /// <ul>
        /// <li><code>defaultOperator</code>: The default operator used to combine individual terms in the search string. For example: <code>defaultOperator: 'or'</code>. For the <code>dismax</code> parser, you specify a percentage that represents the percentage of terms in the search string (rounded down) that must match, rather than a default operator. A value of <code>0%</code> is the equivalent to OR, and a value of <code>100%</code> is equivalent to AND. The percentage must be specified as a value in the range 0-100 followed by the percent (%) symbol. For example, <code>defaultOperator: 50%</code>. Valid values: <code>and</code>, <code>or</code>, a percentage in the range 0%-100% (<code>dismax</code>). Default: <code>and</code> (<code>simple</code>, <code>structured</code>, <code>lucene</code>) or <code>100</code> (<code>dismax</code>). Valid for: <code>simple</code>, <code>structured</code>, <code>lucene</code>, and <code>dismax</code>.</li>
        /// <li><code>fields</code>: An array of the fields to search when no fields are specified in a search. If no fields are specified in a search and this option is not specified, all text and text-array fields are searched. You can specify a weight for each field to control the relative importance of each field when Amazon CloudSearch calculates relevance scores. To specify a field weight, append a caret (<code>^</code>) symbol and the weight to the field name. For example, to boost the importance of the <code>title</code> field over the <code>description</code> field you could specify: <code>"fields":["title^5","description"]</code>.  Valid values: The name of any configured field and an optional numeric value greater than zero. Default: All <code>text</code> and <code>text-array</code> fields. Valid for: <code>simple</code>, <code>structured</code>, <code>lucene</code>, and <code>dismax</code>.</li>
        /// <li><code>operators</code>: An array of the operators or special characters you want to
        /// disable for the simple query parser. If you disable the
        /// <code>and</code>, <code>or</code>, or <code>not</code>
        /// operators, the corresponding operators (<code>+</code>,
        /// <code>|</code>, <code>-</code>) have no special meaning and
        /// are dropped from the search string. Similarly, disabling
        /// <code>prefix</code> disables the wildcard operator
        /// (<code>*</code>) and disabling <code>phrase</code> disables
        /// the ability to search for phrases by enclosing phrases in double
        /// quotes. Disabling precedence disables the ability to control
        /// order of precedence using parentheses. Disabling <code>near</code> disables
        /// the ability to use the ~ operator to perform a sloppy phrase search.
        /// Disabling the <code>fuzzy</code> operator disables the ability to use the ~ operator to perform a fuzzy search.
        /// <code>escape</code> disables the ability to use a backslash
        /// (<code>\</code>) to escape special characters within the
        /// search string. Disabling whitespace is an advanced option that
        /// prevents the parser from tokenizing on whitespace, which can be
        /// useful for Vietnamese. (It prevents Vietnamese words from being
        /// split incorrectly.) For example, you could disable all operators
        /// other than the phrase operator to support just simple term and
        /// phrase queries: <code>"operators":["and","not","or",
        /// "prefix"]</code>. Valid values: <code>and</code>, <code>escape</code>,
        /// <code>fuzzy</code>, <code>near</code>, <code>not</code>, <code>or</code>,
        /// <code>phrase</code>, <code>precedence</code>, <code>prefix</code>,
        /// <code>whitespace</code>. Default: All
        /// operators and special characters are enabled. Valid for:
        /// <code>simple</code>.</li>
        /// <li><code>phraseFields</code>: An array of the <code>text</code> or <code>text-array</code> fields you want to use for
        /// phrase searches. When the terms in the search string appear in
        /// close proximity within a field, the field scores higher. You can
        /// specify a weight for each field to boost that score. The
        /// <code>phraseSlop</code> option controls how much the matches
        /// can deviate from the search string and still be boosted. To
        /// specify a field weight, append a caret (<code>^</code>) symbol
        /// and the weight to the field name. For example, to boost phrase
        /// matches in the <code>title</code> field over the
        /// <code>abstract</code> field, you could specify:
        /// <code>"phraseFields":["title^3",
        /// "plot"]</code>
        /// Valid values: The name of any <code>text</code> or
        /// <code>text-array</code> field and an optional numeric value greater than zero. Default: No fields. If you don't specify any fields with <code>phraseFields</code>, proximity scoring is disabled even if <code>phraseSlop</code> is specified. Valid
        /// for: <code>dismax</code>.</li>
        /// <li><code>phraseSlop</code>: An integer value that specifies how much matches can deviate from the search phrase and still be boosted according to the weights specified in the <code>phraseFields</code> option; for example, <code>phraseSlop: 2</code>. You must also specify <code>phraseFields</code> to enable proximity scoring. Valid values: positive integers. Default: 0. Valid for: <code>dismax</code>.</li>
        /// <li><code>explicitPhraseSlop</code>: An integer value that specifies how much a match can deviate from the search phrase when the phrase is enclosed in double quotes in the search string. (Phrases that exceed this proximity distance are not considered a match.) For example, to specify a slop of three for dismax phrase queries, you would specify <code>"explicitPhraseSlop":3</code>. Valid values: positive integers. Default: 0. Valid for: <code>dismax</code>.</li>
        /// <li><code>tieBreaker</code>: When a term in the search string is found in a document's field, a score is calculated for that field based on how common the word is in that field compared to other documents. If the term occurs in multiple fields within a document, by default only the highest scoring field contributes to the document's overall score. You can specify a <code>tieBreaker</code> value to enable the matches in lower-scoring fields to contribute to the document's score. That way, if two documents have the same max field score for a particular term, the score for the document that has matches in more fields will be higher. The formula for calculating the score with a tieBreaker is <code>(max field score) + (tieBreaker) * (sum of the scores for the rest of the matching fields)</code>.
        ///
        /// Set <code>tieBreaker</code> to 0 to disregard all but the highest scoring field (pure max): <code>"tieBreaker":0</code>. Set to 1 to sum the scores from all fields (pure sum): <code>"tieBreaker":1</code>. Valid values: 0.0 to 1.0. Default: 0.0. Valid for: <code>dismax</code>.
        /// </li>
        /// </ul>
        pub fn set_query_options(
            mut self,
            input: std::option::Option<std::string::String>,
        ) -> Self {
            self.inner = self.inner.set_query_options(input);
            self
        }
        /// <p>Specifies which
        /// query parser to use to process the request. If <code>queryParser</code> is not specified, Amazon CloudSearch
        /// uses the <code>simple</code> query parser. </p>
        /// <p>Amazon CloudSearch supports four query parsers:</p>
        /// <ul>
        /// <li>
        /// <code>simple</code>: perform simple searches of <code>text</code> and
        /// <code>text-array</code> fields. By default, the
        /// <code>simple</code> query parser searches all
        /// <code>text</code> and <code>text-array</code> fields. You
        /// can specify which fields to search by with the
        /// <code>queryOptions</code> parameter. If you prefix a search
        /// term with a plus sign (+) documents must contain the term to be considered a match.
        /// (This is the default, unless you configure the default operator with the <code>queryOptions</code> parameter.)
        /// You can use the <code>-</code> (NOT), <code>|</code>
        /// (OR), and <code>*</code> (wildcard) operators to exclude
        /// particular terms, find results that match any of the specified
        /// terms, or search for a prefix. To search for a phrase rather
        /// than individual terms, enclose the phrase in double quotes. For
        /// more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching-text.html">Searching for Text</a> in the <i>Amazon CloudSearch Developer Guide</i>.
        /// </li>
        /// <li>
        /// <code>structured</code>: perform advanced searches by combining
        /// multiple expressions to define the search criteria. You can also search
        /// within particular fields, search for values and ranges of values, and use
        /// advanced options such as term boosting, <code>matchall</code>, and <code>near</code>.
        /// For more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching-compound-queries.html">Constructing Compound Queries</a> in the <i>Amazon CloudSearch Developer Guide</i>.
        /// </li>
        /// <li>
        /// <code>lucene</code>: search using the Apache Lucene query parser syntax.
        /// For more information, see <a href="http://lucene.apache.org/core/4_6_0/queryparser/org/apache/lucene/queryparser/classic/package-summary.html#package_description">Apache Lucene Query Parser Syntax</a>.
        /// </li>
        /// <li>
        /// <code>dismax</code>: search using the simplified subset of the Apache Lucene query parser syntax
        /// defined by the DisMax query parser.
        /// For more information, see <a href="http://wiki.apache.org/solr/DisMaxQParserPlugin#Query_Syntax">DisMax Query Parser Syntax</a>.
        /// </li>
        ///
        /// </ul>
        pub fn query_parser(mut self, inp: crate::model::QueryParser) -> Self {
            self.inner = self.inner.query_parser(inp);
            self
        }
        /// <p>Specifies which
        /// query parser to use to process the request. If <code>queryParser</code> is not specified, Amazon CloudSearch
        /// uses the <code>simple</code> query parser. </p>
        /// <p>Amazon CloudSearch supports four query parsers:</p>
        /// <ul>
        /// <li>
        /// <code>simple</code>: perform simple searches of <code>text</code> and
        /// <code>text-array</code> fields. By default, the
        /// <code>simple</code> query parser searches all
        /// <code>text</code> and <code>text-array</code> fields. You
        /// can specify which fields to search by with the
        /// <code>queryOptions</code> parameter. If you prefix a search
        /// term with a plus sign (+) documents must contain the term to be considered a match.
        /// (This is the default, unless you configure the default operator with the <code>queryOptions</code> parameter.)
        /// You can use the <code>-</code> (NOT), <code>|</code>
        /// (OR), and <code>*</code> (wildcard) operators to exclude
        /// particular terms, find results that match any of the specified
        /// terms, or search for a prefix. To search for a phrase rather
        /// than individual terms, enclose the phrase in double quotes. For
        /// more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching-text.html">Searching for Text</a> in the <i>Amazon CloudSearch Developer Guide</i>.
        /// </li>
        /// <li>
        /// <code>structured</code>: perform advanced searches by combining
        /// multiple expressions to define the search criteria. You can also search
        /// within particular fields, search for values and ranges of values, and use
        /// advanced options such as term boosting, <code>matchall</code>, and <code>near</code>.
        /// For more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching-compound-queries.html">Constructing Compound Queries</a> in the <i>Amazon CloudSearch Developer Guide</i>.
        /// </li>
        /// <li>
        /// <code>lucene</code>: search using the Apache Lucene query parser syntax.
        /// For more information, see <a href="http://lucene.apache.org/core/4_6_0/queryparser/org/apache/lucene/queryparser/classic/package-summary.html#package_description">Apache Lucene Query Parser Syntax</a>.
        /// </li>
        /// <li>
        /// <code>dismax</code>: search using the simplified subset of the Apache Lucene query parser syntax
        /// defined by the DisMax query parser.
        /// For more information, see <a href="http://wiki.apache.org/solr/DisMaxQParserPlugin#Query_Syntax">DisMax Query Parser Syntax</a>.
        /// </li>
        ///
        /// </ul>
        pub fn set_query_parser(
            mut self,
            input: std::option::Option<crate::model::QueryParser>,
        ) -> Self {
            self.inner = self.inner.set_query_parser(input);
            self
        }
        /// <p>Specifies the field and expression values to include in the response. Multiple fields or expressions are specified as a comma-separated list. By default, a search response includes all
        /// return enabled fields (<code>_all_fields</code>).
        /// To  return only the document IDs for the matching documents,
        /// specify <code>_no_fields</code>.
        /// To retrieve the relevance score calculated for each document,
        /// specify <code>_score</code>.  </p>
        pub fn r#return(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.r#return(inp);
            self
        }
        /// <p>Specifies the field and expression values to include in the response. Multiple fields or expressions are specified as a comma-separated list. By default, a search response includes all
        /// return enabled fields (<code>_all_fields</code>).
        /// To  return only the document IDs for the matching documents,
        /// specify <code>_no_fields</code>.
        /// To retrieve the relevance score calculated for each document,
        /// specify <code>_score</code>.  </p>
        pub fn set_return(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_return(input);
            self
        }
        /// <p>Specifies the maximum number of search hits to include in the response. </p>
        pub fn size(mut self, inp: i64) -> Self {
            self.inner = self.inner.size(inp);
            self
        }
        /// <p>Specifies the maximum number of search hits to include in the response. </p>
        pub fn set_size(mut self, input: std::option::Option<i64>) -> Self {
            self.inner = self.inner.set_size(input);
            self
        }
        /// <p>Specifies the fields or custom expressions to use to sort the search
        /// results. Multiple fields or expressions are specified as a comma-separated list.
        /// You must specify the sort direction (<code>asc</code> or
        /// <code>desc</code>) for each field; for example, <code>year
        /// desc,title asc</code>. To use a field to sort results, the field must be sort-enabled in
        /// the domain configuration. Array type fields cannot be used for sorting.
        /// If no <code>sort</code> parameter is specified, results are sorted by
        /// their default relevance scores in descending order: <code>_score
        /// desc</code>. You can also sort by document ID
        /// (<code>_id asc</code>) and version (<code>_version desc</code>).</p>
        /// <p>For more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/sorting-results.html">Sorting Results</a> in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn sort(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.sort(inp);
            self
        }
        /// <p>Specifies the fields or custom expressions to use to sort the search
        /// results. Multiple fields or expressions are specified as a comma-separated list.
        /// You must specify the sort direction (<code>asc</code> or
        /// <code>desc</code>) for each field; for example, <code>year
        /// desc,title asc</code>. To use a field to sort results, the field must be sort-enabled in
        /// the domain configuration. Array type fields cannot be used for sorting.
        /// If no <code>sort</code> parameter is specified, results are sorted by
        /// their default relevance scores in descending order: <code>_score
        /// desc</code>. You can also sort by document ID
        /// (<code>_id asc</code>) and version (<code>_version desc</code>).</p>
        /// <p>For more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/sorting-results.html">Sorting Results</a> in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn set_sort(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_sort(input);
            self
        }
        /// <p>Specifies the offset of the first search hit you want to return. Note that the result set is zero-based; the first result is at index 0. You can specify either the <code>start</code> or <code>cursor</code> parameter in a request, they are mutually exclusive.  </p>
        /// <p>For more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/paginating-results.html">Paginating Results</a> in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn start(mut self, inp: i64) -> Self {
            self.inner = self.inner.start(inp);
            self
        }
        /// <p>Specifies the offset of the first search hit you want to return. Note that the result set is zero-based; the first result is at index 0. You can specify either the <code>start</code> or <code>cursor</code> parameter in a request, they are mutually exclusive.  </p>
        /// <p>For more information, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/paginating-results.html">Paginating Results</a> in the <i>Amazon CloudSearch Developer Guide</i>.</p>
        pub fn set_start(mut self, input: std::option::Option<i64>) -> Self {
            self.inner = self.inner.set_start(input);
            self
        }
        /// <p>Specifies one or more fields for which to get statistics information. Each specified field must be facet-enabled in the domain configuration. The fields are specified in JSON using the form:</p>
        /// <code>{"FIELD-A":{},"FIELD-B":{}}</code>
        /// <p>There are currently no options supported for statistics.</p>
        pub fn stats(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.stats(inp);
            self
        }
        /// <p>Specifies one or more fields for which to get statistics information. Each specified field must be facet-enabled in the domain configuration. The fields are specified in JSON using the form:</p>
        /// <code>{"FIELD-A":{},"FIELD-B":{}}</code>
        /// <p>There are currently no options supported for statistics.</p>
        pub fn set_stats(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_stats(input);
            self
        }
    }
    /// Fluent builder constructing a request to `Suggest`.
    ///
    /// <p>Retrieves autocomplete suggestions for a partial query string. You can use suggestions enable you to display likely matches before users finish typing. In Amazon CloudSearch, suggestions are based on the contents of a particular text field. When you request suggestions, Amazon CloudSearch finds all of the documents whose values in the suggester field start with the specified query string. The beginning of the field must match the query string to be considered a match. </p>
    /// <p>For more information about configuring suggesters and retrieving suggestions, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-suggestions.html">Getting Suggestions</a> in the <i>Amazon CloudSearch Developer Guide</i>. </p>
    ///
    /// <p>The endpoint for submitting <code>Suggest</code> requests is domain-specific. You submit suggest requests to a domain's search endpoint. To get the search endpoint for your domain, use the Amazon CloudSearch configuration service <code>DescribeDomains</code> action. A domain's endpoints are also displayed on the domain dashboard in the Amazon CloudSearch console. </p>
    #[derive(std::fmt::Debug)]
    pub struct Suggest<
        C = aws_smithy_client::erase::DynConnector,
        M = aws_hyper::AwsMiddleware,
        R = aws_smithy_client::retry::Standard,
    > {
        handle: std::sync::Arc<super::Handle<C, M, R>>,
        inner: crate::input::suggest_input::Builder,
    }
    impl<C, M, R> Suggest<C, M, R>
    where
        C: aws_smithy_client::bounds::SmithyConnector,
        M: aws_smithy_client::bounds::SmithyMiddleware<C>,
        R: aws_smithy_client::retry::NewRequestPolicy,
    {
        /// Creates a new `Suggest`.
        pub(crate) fn new(handle: std::sync::Arc<super::Handle<C, M, R>>) -> Self {
            Self {
                handle,
                inner: Default::default(),
            }
        }

        /// Sends the request and returns the response.
        ///
        /// If an error occurs, an `SdkError` will be returned with additional details that
        /// can be matched against.
        ///
        /// By default, any retryable failures will be retried twice. Retry behavior
        /// is configurable with the [RetryConfig](aws_smithy_types::retry::RetryConfig), which can be
        /// set when configuring the client.
        pub async fn send(
            self,
        ) -> std::result::Result<
            crate::output::SuggestOutput,
            aws_smithy_http::result::SdkError<crate::error::SuggestError>,
        >
        where
            R::Policy: aws_smithy_client::bounds::SmithyRetryPolicy<
                crate::input::SuggestInputOperationOutputAlias,
                crate::output::SuggestOutput,
                crate::error::SuggestError,
                crate::input::SuggestInputOperationRetryAlias,
            >,
        {
            let input = self.inner.build().map_err(|err| {
                aws_smithy_http::result::SdkError::ConstructionFailure(err.into())
            })?;
            let op = input
                .make_operation(&self.handle.conf)
                .await
                .map_err(|err| {
                    aws_smithy_http::result::SdkError::ConstructionFailure(err.into())
                })?;
            self.handle.client.call(op).await
        }
        /// <p>Specifies the string for which you want to get suggestions.</p>
        pub fn query(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.query(inp);
            self
        }
        /// <p>Specifies the string for which you want to get suggestions.</p>
        pub fn set_query(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_query(input);
            self
        }
        /// <p>Specifies the name of the suggester to use to find suggested matches.</p>
        pub fn suggester(mut self, inp: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.suggester(inp);
            self
        }
        /// <p>Specifies the name of the suggester to use to find suggested matches.</p>
        pub fn set_suggester(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_suggester(input);
            self
        }
        /// <p>Specifies the maximum number of suggestions to return. </p>
        pub fn size(mut self, inp: i64) -> Self {
            self.inner = self.inner.size(inp);
            self
        }
        /// <p>Specifies the maximum number of suggestions to return. </p>
        pub fn set_size(mut self, input: std::option::Option<i64>) -> Self {
            self.inner = self.inner.set_size(input);
            self
        }
    }
    /// Fluent builder constructing a request to `UploadDocuments`.
    ///
    /// <p>Posts a batch of documents to a search domain for indexing.  A document batch is a collection of add and delete operations that represent the documents you want to add, update, or delete from your domain. Batches can be described in either JSON or XML. Each item that you want Amazon CloudSearch to return as a search result (such as a product) is represented as a document. Every document has a unique ID and one or more fields that contain the data that you want to search and return in results. Individual documents  cannot contain more than 1 MB of data. The entire batch cannot exceed 5 MB. To get the best possible upload performance, group add and delete operations in batches that are close the 5 MB limit. Submitting a large volume of single-document batches can overload a domain's document service.  </p>
    /// <p>The endpoint for submitting <code>UploadDocuments</code> requests is domain-specific. To get the document endpoint for your domain, use the Amazon CloudSearch configuration service <code>DescribeDomains</code> action. A domain's endpoints are also displayed on the domain dashboard in the Amazon CloudSearch console. </p>
    /// <p>For more information about formatting your data for Amazon CloudSearch, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/preparing-data.html">Preparing Your Data</a> in the <i>Amazon CloudSearch Developer Guide</i>.
    /// For more information about uploading data for indexing, see <a href="http://docs.aws.amazon.com/cloudsearch/latest/developerguide/uploading-data.html">Uploading Data</a> in the <i>Amazon CloudSearch Developer Guide</i>. </p>
    #[derive(std::fmt::Debug)]
    pub struct UploadDocuments<
        C = aws_smithy_client::erase::DynConnector,
        M = aws_hyper::AwsMiddleware,
        R = aws_smithy_client::retry::Standard,
    > {
        handle: std::sync::Arc<super::Handle<C, M, R>>,
        inner: crate::input::upload_documents_input::Builder,
    }
    impl<C, M, R> UploadDocuments<C, M, R>
    where
        C: aws_smithy_client::bounds::SmithyConnector,
        M: aws_smithy_client::bounds::SmithyMiddleware<C>,
        R: aws_smithy_client::retry::NewRequestPolicy,
    {
        /// Creates a new `UploadDocuments`.
        pub(crate) fn new(handle: std::sync::Arc<super::Handle<C, M, R>>) -> Self {
            Self {
                handle,
                inner: Default::default(),
            }
        }

        /// Sends the request and returns the response.
        ///
        /// If an error occurs, an `SdkError` will be returned with additional details that
        /// can be matched against.
        ///
        /// By default, any retryable failures will be retried twice. Retry behavior
        /// is configurable with the [RetryConfig](aws_smithy_types::retry::RetryConfig), which can be
        /// set when configuring the client.
        pub async fn send(
            self,
        ) -> std::result::Result<
            crate::output::UploadDocumentsOutput,
            aws_smithy_http::result::SdkError<crate::error::UploadDocumentsError>,
        >
        where
            R::Policy: aws_smithy_client::bounds::SmithyRetryPolicy<
                crate::input::UploadDocumentsInputOperationOutputAlias,
                crate::output::UploadDocumentsOutput,
                crate::error::UploadDocumentsError,
                crate::input::UploadDocumentsInputOperationRetryAlias,
            >,
        {
            let input = self.inner.build().map_err(|err| {
                aws_smithy_http::result::SdkError::ConstructionFailure(err.into())
            })?;
            let op = input
                .make_operation(&self.handle.conf)
                .await
                .map_err(|err| {
                    aws_smithy_http::result::SdkError::ConstructionFailure(err.into())
                })?;
            self.handle.client.call(op).await
        }
        /// <p>A batch of documents formatted in JSON or HTML.</p>
        pub fn documents(mut self, inp: aws_smithy_http::byte_stream::ByteStream) -> Self {
            self.inner = self.inner.documents(inp);
            self
        }
        /// <p>A batch of documents formatted in JSON or HTML.</p>
        pub fn set_documents(
            mut self,
            input: std::option::Option<aws_smithy_http::byte_stream::ByteStream>,
        ) -> Self {
            self.inner = self.inner.set_documents(input);
            self
        }
        /// <p>The format of the batch you are uploading. Amazon CloudSearch supports two document batch formats:</p>
        /// <ul>
        /// <li>application/json</li>
        /// <li>application/xml</li>
        /// </ul>
        pub fn content_type(mut self, inp: crate::model::ContentType) -> Self {
            self.inner = self.inner.content_type(inp);
            self
        }
        /// <p>The format of the batch you are uploading. Amazon CloudSearch supports two document batch formats:</p>
        /// <ul>
        /// <li>application/json</li>
        /// <li>application/xml</li>
        /// </ul>
        pub fn set_content_type(
            mut self,
            input: std::option::Option<crate::model::ContentType>,
        ) -> Self {
            self.inner = self.inner.set_content_type(input);
            self
        }
    }
}
impl<C> Client<C, aws_hyper::AwsMiddleware, aws_smithy_client::retry::Standard> {
    /// Creates a client with the given service config and connector override.
    pub fn from_conf_conn(conf: crate::Config, conn: C) -> Self {
        let retry_config = conf.retry_config.as_ref().cloned().unwrap_or_default();
        let timeout_config = conf.timeout_config.as_ref().cloned().unwrap_or_default();
        let sleep_impl = conf.sleep_impl.clone();
        let mut client = aws_hyper::Client::new(conn)
            .with_retry_config(retry_config.into())
            .with_timeout_config(timeout_config);

        client.set_sleep_impl(sleep_impl);
        Self {
            handle: std::sync::Arc::new(Handle { client, conf }),
        }
    }
}
impl
    Client<
        aws_smithy_client::erase::DynConnector,
        aws_hyper::AwsMiddleware,
        aws_smithy_client::retry::Standard,
    >
{
    /// Creates a new client from a shared config.
    #[cfg(any(feature = "rustls", feature = "native-tls"))]
    pub fn new(config: &aws_types::config::Config) -> Self {
        Self::from_conf(config.into())
    }

    /// Creates a new client from the service [`Config`](crate::Config).
    #[cfg(any(feature = "rustls", feature = "native-tls"))]
    pub fn from_conf(conf: crate::Config) -> Self {
        let retry_config = conf.retry_config.as_ref().cloned().unwrap_or_default();
        let timeout_config = conf.timeout_config.as_ref().cloned().unwrap_or_default();
        let sleep_impl = conf.sleep_impl.clone();
        let mut client = aws_hyper::Client::https()
            .with_retry_config(retry_config.into())
            .with_timeout_config(timeout_config);

        client.set_sleep_impl(sleep_impl);
        Self {
            handle: std::sync::Arc::new(Handle { client, conf }),
        }
    }
}
